"""Common configuration constants
"""

PROJECTNAME = 'adi.suite'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'Gallery': 'adi.suite: Add Gallery',
    'Suite': 'adi.suite: Add Suite',
}
