/*
 * BASIC SRUCTURE
 *
 */

#fancybox-overlay {
    opacity: 0.666 !important;
}

body.template-adi_call_galleryview #fancybox-overlay {
    background-color: transparent !important;
}

body.template-adi_call_galleryview { 
    background-color: transparent !important; 
}

.template-adi_suite_gallerylist #fancybox-wrap { 
    position: absolute; 
    top: 0!important; 
    left: 0!important; 
    width: 99.5%!important; 
    height: 99.5%!important; 
    padding: 0; 
    overflow: hidden!important;
} 

#fancybox-outer { 
    margin-left: auto!important; 
    margin-right: auto!important; 
} 

.template-adi_suite_gallerylist #fancybox-outer, 
.template-adi_suite_gallerylist #fancybox-inner { 
    width: 100%!important; 
    height: 100%!important; 
    top: 0!important; left: 0!important; 
    background: transparent !important; 
}

.template-adi_suite_gallerylist #fancybox-close { 
    top: 0; 
    right: 0; 
} 

/* TITLE AND DESCRIPTION */

#fancybox-title {
    padding-left: 0 !important;
    padding-right: 0 !important;
    width: 100% !important;
    background: #fff;
    padding: 1em;
}

#fancybox-title-main {
    padding: 1em;
    background-image: url();
    color: #333;
    line-height: 1.5em;
    font-weight: normal;
    text-align: right;
}

#fancybox-title-main * {
    width: 100%;
    padding: 0;
}

#fancybox-title-wrap {
    width: 94%;
}

#fancybox-title-wrap span {
    float: none;
    height: 100%;
}

#fancybox-title-main div:nth-child(2) {
    font-style: italic;
}

#fancybox-title-left,
#fancybox-title-right {
    display: none;
}


/* ARROW AND CLOSE BUTTONS */

#fancybox-close {
    position: absolute;
    top: -27px;
    right: -27px;
}

#fancybox-close,
#fancybox-left-ico,
#fancybox-right-ico {
    background-image: url(++resource++adi_fancybox.png);
    background-repeat: no-repeat;
}

#fancybox-left:hover {
    margin-left: -50px;
    margin-bottom: -10px;
}

#fancybox-right:hover {
    margin-right: -50px;
    margin-bottom: -10px;
}

/* FLOWPLAYER */

.template-adi_suite_flowplayer {
    background: #333;
}

#player {
    display: block;
    height: 330px;
    width: 500px;
    background: url(++resource++play.png) no-repeat -8px -3px;
    position: absolute;
    left: 20px;
    top: 16px;
}

.template-adi_suite_flowplayer #fancybox-frame, 
.template-adi_suite_galleryview #fancybox-frame, 
.template-adi_call_galleryview #fancybox-frame { 
    overflow: hidden; 
}

.template-adi_suite_flowplayer #portal-column-content, 
.template-adi_call_flowplayer #portal-column-content { 
    margin-left: -98.27%; 
    margin-top: -1%;
}

/* NON DISPLAYS */

/* gal */
.template-adi_call_galleryview #visual-portal-wrapper, 
.template-adi_call_galleryview #fancybox-close,
/* all contentypes exept files */
.template-adi_suite_content #portal-top,
.template-adi_suite_content #portal-column-one, 
.template-adi_suite_content #portal-column-two, 
.template-adi_suite_content #portal-breadcrumbs,
.template-adi_suite_content #portal-footer,
.template-adi_suite_content #portal-colophon,
.template-adi_suite_content #portal-siteactions,
.template-adi_suite_content .documentDescription, 
.template-adi_suite_content .documentFirstHeading,
.template-adi_suite_content #content div.documentByLine,
/* contenttype file */
.template-adi_suite_flowplayer #portal-top, 
.template-adi_suite_flowplayer #portal-column-one, 
.template-adi_suite_flowplayer #portal-column-two, 
.template-adi_suite_flowplayer #portal-footer, 
.template-adi_suite_flowplayer #portal-colophon, 
.template-adi_suite_flowplayer #portal-breadcrumbs, 
.template-adi_suite_flowplayer #portal-siteactions, 
.template-adi_suite_flowplayer #edit-bar, 
.template-adi_suite_flowplayer .documentDescription, 
.template-adi_suite_flowplayer .documentFirstHeading,
.template-adi_suite_flowplayer .documentByLine { 
    display: none !important; 
}

/* EOF */
